@@ -13,4 +13,4 @@ class Bootstrap(ComponentResource):
 
         # Create bootstrap resource group
         # bootstrap_rg = resource_group.resource_group('bootstrap', props)
-        shared_res_grp = resource_group("Novari-Shared", props)
+        shared_res_grp = resource_group.resource_group("Novari-Shared", props)
